@@ -41,11 +41,13 @@ class Base(object):
             uri += '/'
         request_url = '{}/v2/{}'.format(self.auth.api_url, uri)
 
-        if type(data) is dict:
+        if type(data) is dict or type(data) is list:
             data = json.dumps(data)
         headers = self._get_headers()
         try:
             if method in ('GET', 'DELETE'):
+                if method == 'GET':
+                    headers.pop('Content-Type')
                 response = self.session.request(
                     method,
                     request_url,
@@ -65,7 +67,11 @@ class Base(object):
             raise exceptions.ApiError('Error in request')
 
         else:
-            content = response.json()
+            try:
+                content = response.json()
+            except json.JSONDecodeError:
+                content = response.content
+
             status_code = response.status_code
 
             if self.logger.isEnabledFor(logging.DEBUG):
